|pypi| |travis| |black|

Python Cafeteria Package
========================

A convenience package providing various building blocks for pythonic patterns.


.. |pypi| image:: https://badge.fury.io/py/python-cafe.svg
    :target: https://badge.fury.io/py/python-cafe
.. |travis| image:: https://travis-ci.org/abn/cafeteria.svg?branch=master
    :target: https://travis-ci.org/abn/cafeteria
.. |black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/ambv/black
